summaryrefslogtreecommitdiffstats
path: root/kexi/migration/migratemanager_p.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/migration/migratemanager_p.h')
-rw-r--r--kexi/migration/migratemanager_p.h23
1 files changed, 12 insertions, 11 deletions
diff --git a/kexi/migration/migratemanager_p.h b/kexi/migration/migratemanager_p.h
index 0d90acfe..59824573 100644
--- a/kexi/migration/migratemanager_p.h
+++ b/kexi/migration/migratemanager_p.h
@@ -20,22 +20,23 @@
#ifndef KEXI_MIGRATE_MNGR_P_H
#define KEXI_MIGRATE_MNGR_P_H
-#include <qobject.h>
-#include <qasciidict.h>
+#include <tqobject.h>
+#include <tqasciidict.h>
namespace KexiMigration {
/*! Internal class of driver manager.
*/
-class MigrateManagerInternal : public QObject, public KexiDB::Object
+class MigrateManagerInternal : public TQObject, public KexiDB::Object
{
Q_OBJECT
+ TQ_OBJECT
public:
~MigrateManagerInternal();
/*! Tries to load db driver \a name.
\return db driver, or 0 if error (then error message is also set) */
- KexiMigrate* driver(const QString& name);
+ KexiMigrate* driver(const TQString& name);
static MigrateManagerInternal *self();
@@ -47,9 +48,9 @@ class MigrateManagerInternal : public QObject, public KexiDB::Object
void decRefCount();
protected slots:
/*! Used to destroy all drivers on QApplication quit, so even if there are
DriverManager's static instances that are destroyed on program
- "static destruction", drivers are not kept after QApplication death.
+ "static destruction", drivers are not kept after TQApplication death.
*/
void slotAppQuits();
@@ -65,18 +66,18 @@ class MigrateManagerInternal : public QObject, public KexiDB::Object
MigrateManager::ServicesMap m_services_lcase; //! as above but service names in lowercase
MigrateManager::ServicesMap m_services_by_mimetype;
- QAsciiDict<KexiMigrate> m_drivers;
+ TQAsciiDict<KexiMigrate> m_drivers;
ulong m_refCount;
- QString m_serverErrMsg;
+ TQString m_serverErrMsg;
int m_serverResultNum;
- QString m_serverResultName;
+ TQString m_serverResultName;
//! result names for KParts::ComponentFactory::ComponentLoadingError
- QMap<int,QString> m_componentLoadingErrors;
+ TQMap<int,TQString> m_componentLoadingErrors;
bool lookupDriversNeeded : 1;
- QStringList possibleProblems;
+ TQStringList possibleProblems;
friend class MigrateManager;
};
@@ -47,9 +48,9 @@ class MigrateManagerInternal : public QObject, public KexiDB::Object
void decRefCount();
protected slots:
- /*! Used to destroy all drivers on QApplication quit, so even if there are
+ /*! Used to destroy all drivers on TQApplication quit, so even if there are
DriverManager's static instances that are destroyed on program